← Back to team overview

t-kernel-zh team mailing list archive

Re: [Open T-Kernel] KBuild 的编译输出文件从 vmlinux 改为 vmtronx

 

----8<----------------------------------------------------------------
>From 50ddb5d59b06b12445b680989cb055f6a72b89ce Mon Sep 17 00:00:00 2001
From: Du Huanpeng <u74147@xxxxxxxxx>
Date: Sat, 7 Jan 2017 13:55:13 +0800
Subject: [PATCH] KBuild: rename vmlinux to vmtronx

rename vmlinuz to vmtronz too.

Signed-off-by: Du Huanpeng <u74147@xxxxxxxxx>
---
 tkernel_source/.gitignore                          |  8 +--
 .../ABI/testing/sysfs-kernel-livepatch             |  2 +-
 tkernel_source/Documentation/BUG-HUNTING           |  8 +--
 tkernel_source/Documentation/DocBook/kgdb.tmpl     |  8 +--
 tkernel_source/Documentation/arm/nwfpe/README.FPE  |  2 +-
 tkernel_source/Documentation/basic_profiling.txt   |  8 +--
 .../Documentation/debugging-via-ohci1394.txt       |  2 +-
 .../devicetree/bindings/common-properties.txt      |  4 +-
 tkernel_source/Documentation/dontdiff              | 14 ++--
 .../filesystems/ramfs-rootfs-initramfs.txt         |  2 +-
 tkernel_source/Documentation/frv/gdbstub.txt       |  2 +-
 .../Documentation/gdb-kernel-debugging.txt         |  6 +-
 tkernel_source/Documentation/ia64/xen.txt          | 10 +--
 tkernel_source/Documentation/intel_txt.txt         |  2 +-
 tkernel_source/Documentation/kbuild/kbuild.txt     | 10 +--
 tkernel_source/Documentation/kbuild/makefiles.txt  | 60 ++++++++---------
 tkernel_source/Documentation/kbuild/modules.txt    |  6 +-
 tkernel_source/Documentation/kdump/kdump.txt       | 22 +++---
 tkernel_source/Documentation/kmemcheck.txt         | 12 ++--
 tkernel_source/Documentation/kprobes.txt           |  2 +-
 tkernel_source/Documentation/module-signing.txt    |  4 +-
 tkernel_source/Documentation/networking/cxgb.txt   |  2 +-
 tkernel_source/Documentation/oops-tracing.txt      |  2 +-
 .../Documentation/power/swsusp-dmcrypt.txt         |  2 +-
 .../Documentation/powerpc/bootwrapper.txt          |  6 +-
 tkernel_source/Documentation/serial/moxa-smartio   |  6 +-
 tkernel_source/Documentation/sh/new-machine.txt    |  2 +-
 .../Documentation/x86/exception-tables.txt         | 14 ++--
 .../Documentation/zh_CN/basic_profiling.txt        | 10 +--
 .../Documentation/zh_CN/oops-tracing.txt           |  2 +-
 tkernel_source/scripts/Makefile                    |  2 +-
 tkernel_source/scripts/Makefile.lib                |  2 +-
 tkernel_source/scripts/Makefile.modpost            |  6 +-
 tkernel_source/scripts/checkpatch.pl               |  8 +--
 tkernel_source/scripts/checkstack.pl               |  2 +-
 tkernel_source/scripts/decode_stacktrace.sh        | 10 +--
 tkernel_source/scripts/extract-vmtronx             | 14 ++--
 tkernel_source/scripts/gdb/linux/symbols.py        |  8 +--
 tkernel_source/scripts/kallsyms.c                  |  2 +-
 .../scripts/kconfig/streamline_config.pl           |  4 +-
 tkernel_source/scripts/link-vmtronx.sh             | 78 +++++++++++-----------
 tkernel_source/scripts/markup_oops.pl              | 12 ++--
 tkernel_source/scripts/mksysmap                    |  4 +-
 tkernel_source/scripts/mod/modpost.c               | 54 +++++++--------
 tkernel_source/scripts/namespace.pl                |  4 +-
 tkernel_source/scripts/package/builddeb            | 10 +--
 tkernel_source/scripts/package/buildtar            | 50 +++++++-------
 tkernel_source/scripts/package/mkspec              | 30 ++++-----
 tkernel_source/scripts/recordmcount.pl             |  2 +-
 tkernel_source/scripts/sortextable.c               |  4 +-
 tkernel_source/sysdepend/arm/Makefile.linux        |  6 +-
 51 files changed, 276 insertions(+), 276 deletions(-)

diff --git a/tkernel_source/.gitignore b/tkernel_source/.gitignore
index cf19c4f..029a340 100644
--- a/tkernel_source/.gitignore
+++ b/tkernel_source/.gitignore
@@ -44,10 +44,10 @@ Module.symvers
 /tags
 /TAGS
 /linux
-/vmlinux
-/vmlinux.32
-/vmlinux-gdb.py
-/vmlinuz
+/vmtronx
+/vmtronx.32
+/vmtronx-gdb.py
+/vmtronz
 /System.map
 /Module.markers
 
diff --git a/tkernel_source/Documentation/ABI/testing/sysfs-kernel-livepatch b/tkernel_source/Documentation/ABI/testing/sysfs-kernel-livepatch
index 5bf42a8..e726cc0 100644
--- a/tkernel_source/Documentation/ABI/testing/sysfs-kernel-livepatch
+++ b/tkernel_source/Documentation/ABI/testing/sysfs-kernel-livepatch
@@ -14,7 +14,7 @@ KernelVersion:	3.19.0
 Contact:	live-patching@xxxxxxxxxxxxxxx
 Description:
 		The patch directory contains subdirectories for each kernel
-		object (vmlinux or a module) in which it patched functions.
+		object (vmtronx or a module) in which it patched functions.
 
 What:		/sys/kernel/livepatch/<patch>/enabled
 Date:		Nov 2014
diff --git a/tkernel_source/Documentation/BUG-HUNTING b/tkernel_source/Documentation/BUG-HUNTING
index 65022a8..0086f3b 100644
--- a/tkernel_source/Documentation/BUG-HUNTING
+++ b/tkernel_source/Documentation/BUG-HUNTING
@@ -192,7 +192,7 @@ e.g. crash dump output as shown by Dave Miller.
 >        mov        0x13c(%ebx), %eax       ! %eax = inet_sk(sk)->opt
 
 In addition, you can use GDB to figure out the exact file and line
-number of the OOPS from the vmlinux file. If you have
+number of the OOPS from the vmtronx file. If you have
 CONFIG_DEBUG_INFO enabled, you can simply copy the EIP value from the
 OOPS:
 
@@ -200,7 +200,7 @@ OOPS:
 
 And use GDB to translate that to human-readable form:
 
-  gdb vmlinux
+  gdb vmtronx
   (gdb) l *0xc021e50e
 
 If you don't have CONFIG_DEBUG_INFO enabled, you use the function
@@ -210,8 +210,8 @@ offset from the OOPS:
 
 And recompile the kernel with CONFIG_DEBUG_INFO enabled:
 
-  make vmlinux
-  gdb vmlinux
+  make vmtronx
+  gdb vmtronx
   (gdb) p vt_ioctl
   (gdb) l *(0x<address of vt_ioctl> + 0xda8)
 or, as one command
diff --git a/tkernel_source/Documentation/DocBook/kgdb.tmpl b/tkernel_source/Documentation/DocBook/kgdb.tmpl
index f3abca7..ae3883f 100644
--- a/tkernel_source/Documentation/DocBook/kgdb.tmpl
+++ b/tkernel_source/Documentation/DocBook/kgdb.tmpl
@@ -74,7 +74,7 @@
     Two machines are required for using kgdb. One of these machines is
     a development machine and the other is the target machine.  The
     kernel to be debugged runs on the target machine. The development
-    machine runs an instance of gdb against the vmlinux file which
+    machine runs an instance of gdb against the vmtronx file which
     contains the symbols (not a boot image such as bzImage, zImage,
     uImage...).  In gdb the developer specifies the connection
     parameters and connects to kgdb.  The type of connection a
@@ -99,7 +99,7 @@
     </para>
     <para>
     While it is not a hard requirement that you have symbols in your
-    vmlinux file, gdb tends not to be very useful without the symbolic
+    vmtronx file, gdb tends not to be very useful without the symbolic
     data, so you will want to turn
     on <symbol>CONFIG_DEBUG_INFO</symbol> which is called "Compile the
     kernel with debug info" in the config menu.
@@ -538,7 +538,7 @@
     Example (using a directly connected port):
     </para>
     <programlisting>
-    % gdb ./vmlinux
+    % gdb ./vmtronx
     (gdb) set remotebaud 115200
     (gdb) target remote /dev/ttyS0
     </programlisting>
@@ -546,7 +546,7 @@
     Example (kgdb to a terminal server on TCP port 2012):
     </para>
     <programlisting>
-    % gdb ./vmlinux
+    % gdb ./vmtronx
     (gdb) target remote 192.168.2.2:2012
     </programlisting>
     <para>
diff --git a/tkernel_source/Documentation/arm/nwfpe/README.FPE b/tkernel_source/Documentation/arm/nwfpe/README.FPE
index 26f5d7b..ebe45db 100644
--- a/tkernel_source/Documentation/arm/nwfpe/README.FPE
+++ b/tkernel_source/Documentation/arm/nwfpe/README.FPE
@@ -144,7 +144,7 @@ have a bug in them that prevents the module from generating a SIGFPE.  This
 is caused by a failure to alias fp_current to the kernel variable
 current_set[0] correctly.
 
-The kernel provided with this distribution (vmlinux-nwfpe-0.93) contains
+The kernel provided with this distribution (vmtronx-nwfpe-0.93) contains
 a fix for this problem and also incorporates the current version of the
 emulator directly.  It is possible to run with no floating point module
 loaded with this kernel.  It is provided as a demonstration of the 
diff --git a/tkernel_source/Documentation/basic_profiling.txt b/tkernel_source/Documentation/basic_profiling.txt
index 8764e9f..397ce72 100644
--- a/tkernel_source/Documentation/basic_profiling.txt
+++ b/tkernel_source/Documentation/basic_profiling.txt
@@ -4,10 +4,10 @@ correct my mistakes ;-)    (mbligh@xxxxxxxxxxx)
 Thanks to John Levon, Dave Hansen, et al. for help writing this.
 
 <test> is the thing you're trying to measure.
-Make sure you have the correct System.map / vmlinux referenced!
+Make sure you have the correct System.map / vmtronx referenced!
 
 It is probably easiest to use "make install" for linux and hack
-/sbin/installkernel to copy vmlinux to /boot, in addition to vmlinuz,
+/sbin/installkernel to copy vmtronx to /boot, in addition to vmtronz,
 config, System.map, which are usually installed by default.
 
 Readprofile
@@ -42,7 +42,7 @@ a 0Hz CPU, APIC was not on. Be aware that idle=poll may mean a performance
 penalty.
 
 One time setup:
-		opcontrol --setup --vmlinux=/boot/vmlinux
+		opcontrol --setup --vmtronx=/boot/vmtronx
 
 clear		opcontrol --reset
 start		opcontrol --start
@@ -50,7 +50,7 @@ start		opcontrol --start
 stop		opcontrol --stop
 dump output	opreport >  output_file
 
-To only report on the kernel, run opreport -l /boot/vmlinux > output_file
+To only report on the kernel, run opreport -l /boot/vmtronx > output_file
 
 A reset is needed to clear old statistics, which survive a reboot.
 
diff --git a/tkernel_source/Documentation/debugging-via-ohci1394.txt b/tkernel_source/Documentation/debugging-via-ohci1394.txt
index 5c9a567..8ce4bdf 100644
--- a/tkernel_source/Documentation/debugging-via-ohci1394.txt
+++ b/tkernel_source/Documentation/debugging-via-ohci1394.txt
@@ -68,7 +68,7 @@ and he implemented fast system dump (alpha version - read README.txt):
 - http://halobates.de/firewire/firedump-0.1.tar.bz2
 
 There is also a gdb proxy for firewire which allows to use gdb to access
-data which can be referenced from symbols found by gdb in vmlinux:
+data which can be referenced from symbols found by gdb in vmtronx:
 - http://halobates.de/firewire/fireproxy-0.33.tar.bz2
 
 The latest version of this gdb proxy (fireproxy-0.34) can communicate (not
diff --git a/tkernel_source/Documentation/devicetree/bindings/common-properties.txt b/tkernel_source/Documentation/devicetree/bindings/common-properties.txt
index 3193979..8883d4d 100644
--- a/tkernel_source/Documentation/devicetree/bindings/common-properties.txt
+++ b/tkernel_source/Documentation/devicetree/bindings/common-properties.txt
@@ -13,8 +13,8 @@ Optional properties:
    unconditionally (e.g. readl/writel).  Use this if you know the
    peripheral always needs to be accessed in LE mode.
  - native-endian: Boolean; always use register accesses matched to the
-   endianness of the kernel binary (e.g. LE vmlinux -> readl/writel,
-   BE vmlinux -> ioread32be/iowrite32be).  In this case no byteswaps
+   endianness of the kernel binary (e.g. LE vmtronx -> readl/writel,
+   BE vmtronx -> ioread32be/iowrite32be).  In this case no byteswaps
    will ever be performed.  Use this if the hardware "self-adjusts"
    register endianness based on the CPU's configured endianness.
 
diff --git a/tkernel_source/Documentation/dontdiff b/tkernel_source/Documentation/dontdiff
index 9de9813..f4ae39b 100644
--- a/tkernel_source/Documentation/dontdiff
+++ b/tkernel_source/Documentation/dontdiff
@@ -95,7 +95,7 @@ bounds.h
 bsetup
 btfixupprep
 build
-bvmlinux
+bvmtronx
 bzImage*
 capability_names.h
 capflags.c
@@ -240,12 +240,12 @@ vdso64.lds
 vdso64.so.dbg
 version.h*
 vmImage
-vmlinux
-vmlinux-*
-vmlinux.aout
-vmlinux.bin.all
-vmlinux.lds
-vmlinuz
+vmtronx
+vmtronx-*
+vmtronx.aout
+vmtronx.bin.all
+vmtronx.lds
+vmtronz
 voffset.h
 vsyscall.lds
 vsyscall_32.lds
diff --git a/tkernel_source/Documentation/filesystems/ramfs-rootfs-initramfs.txt b/tkernel_source/Documentation/filesystems/ramfs-rootfs-initramfs.txt
index b176928..3887e3f 100644
--- a/tkernel_source/Documentation/filesystems/ramfs-rootfs-initramfs.txt
+++ b/tkernel_source/Documentation/filesystems/ramfs-rootfs-initramfs.txt
@@ -270,7 +270,7 @@ User Mode Linux, like so:
   gcc -static hello.c -o init
   echo init | cpio -o -H newc | gzip > test.cpio.gz
   # Testing external initramfs using the initrd loading mechanism.
-  qemu -kernel /boot/vmlinuz -initrd test.cpio.gz /dev/zero
+  qemu -kernel /boot/vmtronz -initrd test.cpio.gz /dev/zero
 
 When debugging a normal root filesystem, it's nice to be able to boot with
 "init=/bin/sh".  The initramfs equivalent is "rdinit=/bin/sh", and it's
diff --git a/tkernel_source/Documentation/frv/gdbstub.txt b/tkernel_source/Documentation/frv/gdbstub.txt
index b92bfd9..5d0d600 100644
--- a/tkernel_source/Documentation/frv/gdbstub.txt
+++ b/tkernel_source/Documentation/frv/gdbstub.txt
@@ -79,7 +79,7 @@ Then start GDB in the base of the kernel tree:
 
 Or:
 
-	frv-uclinux-gdb vmlinux		[MMU linux]
+	frv-uclinux-gdb vmtronx		[MMU linux]
 
 When the prompt appears:
 
diff --git a/tkernel_source/Documentation/gdb-kernel-debugging.txt b/tkernel_source/Documentation/gdb-kernel-debugging.txt
index 7050ce8..3367799 100644
--- a/tkernel_source/Documentation/gdb-kernel-debugging.txt
+++ b/tkernel_source/Documentation/gdb-kernel-debugging.txt
@@ -44,10 +44,10 @@ Setup
 
  o cd /path/to/linux-build
 
- o Start gdb: gdb vmlinux
+ o Start gdb: gdb vmtronx
 
    Note: Some distros may restrict auto-loading of gdb scripts to known safe
-   directories. In case gdb reports to refuse loading vmlinux-gdb.py, add
+   directories. In case gdb reports to refuse loading vmtronx-gdb.py, add
 
     add-auto-load-safe-path /path/to/linux-build
 
@@ -62,7 +62,7 @@ Examples of using the Linux-provided gdb helpers
 
  o Load module (and main kernel) symbols:
     (gdb) lx-symbols
-    loading vmlinux
+    loading vmtronx
     scanning for modules in /home/user/linux/build
     loading @0xffffffffa0020000: /home/user/linux/build/net/netfilter/xt_tcpudp.ko
     loading @0xffffffffa0016000: /home/user/linux/build/net/netfilter/xt_pkttype.ko
diff --git a/tkernel_source/Documentation/ia64/xen.txt b/tkernel_source/Documentation/ia64/xen.txt
index c61a99f..381068b 100644
--- a/tkernel_source/Documentation/ia64/xen.txt
+++ b/tkernel_source/Documentation/ia64/xen.txt
@@ -36,8 +36,8 @@ Getting and Building Xen and Dom0
 
  4. copy kernels and xen
     # cp xen/xen.gz /boot/efi/efi/redhat/
-    # cp build-linux-2.6.18-xen_ia64/vmlinux.gz \
-      /boot/efi/efi/redhat/vmlinuz-2.6.18.8-xen
+    # cp build-linux-2.6.18-xen_ia64/vmtronx.gz \
+      /boot/efi/efi/redhat/vmtronz-2.6.18.8-xen
 
  5. make initrd for Dom0/DomU
     # make -C linux-2.6.18-xen.hg ARCH=ia64 modules_install \
@@ -104,7 +104,7 @@ Boot Xen & Domain0
      default=xen
      relocatable
 
-     image=vmlinuz-2.6.18.8-xen
+     image=vmtronz-2.6.18.8-xen
              label=xen
              vmm=xen.gz
              initrd=initrd-2.6.18.8-xen.img
@@ -145,7 +145,7 @@ Getting and Building domU with pv_ops
     # make
 
  5. install the kernel and initrd
-    # cp vmlinux.gz /boot/efi/efi/redhat/vmlinuz-2.6-pv_ops-xenU
+    # cp vmtronx.gz /boot/efi/efi/redhat/vmtronz-2.6-pv_ops-xenU
     # make modules_install
     # mkinitrd -f /boot/efi/efi/redhat/initrd-2.6-pv_ops-xenU.img \
       2.6.26-rc3xen-ia64-08941-g1b12161 --builtin mptspi \
@@ -158,7 +158,7 @@ Boot DomainU with pv_ops
 
  1. make config of DomU
    # vi /etc/xen/rhel5
-     kernel = "/boot/efi/efi/redhat/vmlinuz-2.6-pv_ops-xenU"
+     kernel = "/boot/efi/efi/redhat/vmtronz-2.6-pv_ops-xenU"
      ramdisk = "/boot/efi/efi/redhat/initrd-2.6-pv_ops-xenU.img"
      vcpus = 1
      memory = 512
diff --git a/tkernel_source/Documentation/intel_txt.txt b/tkernel_source/Documentation/intel_txt.txt
index 91d89c5..4911b92 100644
--- a/tkernel_source/Documentation/intel_txt.txt
+++ b/tkernel_source/Documentation/intel_txt.txt
@@ -185,7 +185,7 @@ grub.conf needs to be modified as follows:
         title Linux 2.6.29-tip w/ tboot
           root (hd0,0)
                 kernel /tboot.gz logging=serial,vga,memory
-                module /vmlinuz-2.6.29-tip intel_iommu=on ro
+                module /vmtronz-2.6.29-tip intel_iommu=on ro
                        root=LABEL=/ rhgb console=ttyS0,115200 3
                 module /initrd-2.6.29-tip.img
                 module /Q35_SINIT_17.BIN
diff --git a/tkernel_source/Documentation/kbuild/kbuild.txt b/tkernel_source/Documentation/kbuild/kbuild.txt
index 6466704..fb1df62 100644
--- a/tkernel_source/Documentation/kbuild/kbuild.txt
+++ b/tkernel_source/Documentation/kbuild/kbuild.txt
@@ -50,9 +50,9 @@ LDFLAGS_MODULE
 --------------------------------------------------
 Additional options used for $(LD) when linking modules.
 
-LDFLAGS_vmlinux
+LDFLAGS_vmtronx
 --------------------------------------------------
-Additional options passed to final link of vmlinux.
+Additional options passed to final link of vmtronx.
 
 KBUILD_VERBOSE
 --------------------------------------------------
@@ -225,11 +225,11 @@ The linker script with full path. Assigned by the top-level Makefile.
 
 KBUILD_VMLINUX_INIT
 --------------------------------------------------
-All object files for the init (first) part of vmlinux.
+All object files for the init (first) part of vmtronx.
 Files specified with KBUILD_VMLINUX_INIT are linked first.
 
 KBUILD_VMLINUX_MAIN
 --------------------------------------------------
-All object files for the main part of vmlinux.
+All object files for the main part of vmtronx.
 KBUILD_VMLINUX_INIT and KBUILD_VMLINUX_MAIN together specify
-all the object files used to link vmlinux.
+all the object files used to link vmtronx.
diff --git a/tkernel_source/Documentation/kbuild/makefiles.txt b/tkernel_source/Documentation/kbuild/makefiles.txt
index d2b1c40..fb9d13a 100644
--- a/tkernel_source/Documentation/kbuild/makefiles.txt
+++ b/tkernel_source/Documentation/kbuild/makefiles.txt
@@ -66,7 +66,7 @@ The Makefiles have five parts:
 The top Makefile reads the .config file, which comes from the kernel
 configuration process.
 
-The top Makefile is responsible for building two major products: vmlinux
+The top Makefile is responsible for building two major products: vmtronx
 (the resident kernel image) and modules (any module files).
 It builds these goals by recursively descending into the subdirectories of
 the kernel source tree.
@@ -147,13 +147,13 @@ more details, with real examples.
 
 --- 3.2 Built-in object goals - obj-y
 
-	The kbuild Makefile specifies object files for vmlinux
+	The kbuild Makefile specifies object files for vmtronx
 	in the $(obj-y) lists.  These lists depend on the kernel
 	configuration.
 
 	Kbuild compiles all the $(obj-y) files.  It then calls
 	"$(LD) -r" to merge these files into one built-in.o file.
-	built-in.o is later linked into vmlinux by the parent Makefile.
+	built-in.o is later linked into vmtronx by the parent Makefile.
 
 	The order of files in $(obj-y) is significant.  Duplicates in
 	the lists are allowed: the first instance will be linked into
@@ -408,7 +408,7 @@ more details, with real examples.
 
 	Example:
 		#arch/blackfin/boot/Makefile
-		$(obj)/vmImage: $(obj)/vmlinux.gz
+		$(obj)/vmImage: $(obj)/vmtronx.gz
 			$(call if_changed,uimage)
 			@$(kecho) 'Kernel: $@ is ready'
 
@@ -593,7 +593,7 @@ more details, with real examples.
 
 	Example:
 		#Makefile
-		LDFLAGS_vmlinux += $(call ld-option, -X)
+		LDFLAGS_vmtronx += $(call ld-option, -X)
 
 
 === 4 Host Program support
@@ -823,7 +823,7 @@ When kbuild executes, the following steps are followed (roughly):
 4) Recursively descend down in all directories listed in
    init-* core* drivers-* net-* libs-* and build all targets.
    - The values of the above variables are expanded in arch/$(ARCH)/Makefile.
-5) All object files are then linked and the resulting file vmlinux is
+5) All object files are then linked and the resulting file vmtronx is
    located at the root of the obj tree.
    The very first objects linked are listed in head-y, assigned by
    arch/$(ARCH)/Makefile.
@@ -852,33 +852,33 @@ When kbuild executes, the following steps are followed (roughly):
 	linking the .ko files used for modules.
 	Default is "-r", for relocatable output.
 
-    LDFLAGS_vmlinux	Options for $(LD) when linking vmlinux
+    LDFLAGS_vmtronx	Options for $(LD) when linking vmtronx
 
-	LDFLAGS_vmlinux is used to specify additional flags to pass to
-	the linker when linking the final vmlinux image.
-	LDFLAGS_vmlinux uses the LDFLAGS_$@ support.
+	LDFLAGS_vmtronx is used to specify additional flags to pass to
+	the linker when linking the final vmtronx image.
+	LDFLAGS_vmtronx uses the LDFLAGS_$@ support.
 
 	Example:
 		#arch/x86/Makefile
-		LDFLAGS_vmlinux := -e stext
+		LDFLAGS_vmtronx := -e stext
 
     OBJCOPYFLAGS	objcopy flags
 
 	When $(call if_changed,objcopy) is used to translate a .o file,
 	the flags specified in OBJCOPYFLAGS will be used.
 	$(call if_changed,objcopy) is often used to generate raw binaries on
-	vmlinux.
+	vmtronx.
 
 	Example:
 		#arch/s390/Makefile
 		OBJCOPYFLAGS := -O binary
 
 		#arch/s390/boot/Makefile
-		$(obj)/image: vmlinux FORCE
+		$(obj)/image: vmtronx FORCE
 			$(call if_changed,objcopy)
 
 	In this example, the binary $(obj)/image is a binary version of
-	vmlinux. The usage of $(call if_changed,xxx) will be described later.
+	vmtronx. The usage of $(call if_changed,xxx) will be described later.
 
     KBUILD_AFLAGS		$(AS) assembler flags
 
@@ -992,14 +992,14 @@ When kbuild executes, the following steps are followed (roughly):
 --- 6.4 List directories to visit when descending
 
 	An arch Makefile cooperates with the top Makefile to define variables
-	which specify how to build the vmlinux file.  Note that there is no
+	which specify how to build the vmtronx file.  Note that there is no
 	corresponding arch-specific section for modules; the module-building
 	machinery is all architecture-independent.
 
 
     head-y, init-y, core-y, libs-y, drivers-y, net-y
 
-	$(head-y) lists objects to be linked first in vmlinux.
+	$(head-y) lists objects to be linked first in vmtronx.
 	$(libs-y) lists directories where a lib.a archive can be located.
 	The rest list directories where a built-in.o object file can be
 	located.
@@ -1020,7 +1020,7 @@ When kbuild executes, the following steps are followed (roughly):
 
 --- 6.5 Architecture-specific boot images
 
-	An arch Makefile specifies goals that take the vmlinux file, compress
+	An arch Makefile specifies goals that take the vmtronx file, compress
 	it, wrap it in bootstrapping code, and copy the resulting files
 	somewhere. This includes various kinds of installation commands.
 	The actual goals are not standardized across architectures.
@@ -1039,7 +1039,7 @@ When kbuild executes, the following steps are followed (roughly):
 	Example:
 		#arch/x86/Makefile
 		boot := arch/x86/boot
-		bzImage: vmlinux
+		bzImage: vmtronx
 			$(Q)$(MAKE) $(build)=$(boot) $(boot)/$@
 
 	"$(Q)$(MAKE) $(build)=<dir>" is the recommended way to invoke
@@ -1061,7 +1061,7 @@ When kbuild executes, the following steps are followed (roughly):
 	An architecture shall always, per default, build a bootable image.
 	In "make help", the default goal is highlighted with a '*'.
 	Add a new prerequisite to all: to select a default goal different
-	from vmlinux.
+	from vmtronx.
 
 	Example:
 		#arch/x86/Makefile
@@ -1156,7 +1156,7 @@ When kbuild executes, the following steps are followed (roughly):
 
     dtc
 	Create flattened device tree blob object suitable for linking
-	into vmlinux. Device tree blobs linked into vmlinux are placed
+	into vmtronx. Device tree blobs linked into vmtronx are placed
 	in an init section in the image. Platform code *must* copy the
 	blob to non-init memory prior to calling unflatten_device_tree().
 
@@ -1184,10 +1184,10 @@ When kbuild executes, the following steps are followed (roughly):
 		#
 		quiet_cmd_image = BUILD   $@
 		      cmd_image = $(obj)/tools/build $(BUILDFLAGS) \
-		                                     $(obj)/vmlinux.bin > $@
+		                                     $(obj)/vmtronx.bin > $@
 
 		targets += bzImage
-		$(obj)/bzImage: $(obj)/vmlinux.bin $(obj)/tools/build FORCE
+		$(obj)/bzImage: $(obj)/vmtronx.bin $(obj)/tools/build FORCE
 			$(call if_changed,image)
 			@echo 'Kernel: $@ is ready'
 
@@ -1200,23 +1200,23 @@ When kbuild executes, the following steps are followed (roughly):
 
 --- 6.9 Preprocessing linker scripts
 
-	When the vmlinux image is built, the linker script
-	arch/$(ARCH)/kernel/vmlinux.lds is used.
-	The script is a preprocessed variant of the file vmlinux.lds.S
+	When the vmtronx image is built, the linker script
+	arch/$(ARCH)/kernel/vmtronx.lds is used.
+	The script is a preprocessed variant of the file vmtronx.lds.S
 	located in the same directory.
 	kbuild knows .lds files and includes a rule *lds.S -> *lds.
 
 	Example:
 		#arch/x86/kernel/Makefile
-		always := vmlinux.lds
+		always := vmtronx.lds
 
 		#Makefile
-		export CPPFLAGS_vmlinux.lds += -P -C -U$(ARCH)
+		export CPPFLAGS_vmtronx.lds += -P -C -U$(ARCH)
 
 	The assignment to $(always) is used to tell kbuild to build the
-	target vmlinux.lds.
-	The assignment to $(CPPFLAGS_vmlinux.lds) tells kbuild to use the
-	specified options when building the target vmlinux.lds.
+	target vmtronx.lds.
+	The assignment to $(CPPFLAGS_vmtronx.lds) tells kbuild to use the
+	specified options when building the target vmtronx.lds.
 
 	When building the *.lds target, kbuild uses the variables:
 	KBUILD_CPPFLAGS	: Set in top-level Makefile
diff --git a/tkernel_source/Documentation/kbuild/modules.txt b/tkernel_source/Documentation/kbuild/modules.txt
index 3fb39e0..ca0e598 100644
--- a/tkernel_source/Documentation/kbuild/modules.txt
+++ b/tkernel_source/Documentation/kbuild/modules.txt
@@ -23,7 +23,7 @@ This document describes how to build an out-of-tree kernel module.
 	   --- 5.1 INSTALL_MOD_PATH
 	   --- 5.2 INSTALL_MOD_DIR
 	=== 6. Module Versioning
-	   --- 6.1 Symbols From the Kernel (vmlinux + modules)
+	   --- 6.1 Symbols From the Kernel (vmtronx + modules)
 	   --- 6.2 Symbols and External Modules
 	   --- 6.3 Symbols From Another External Module
 	=== 7. Tips & Tricks
@@ -435,7 +435,7 @@ module.
 Module.symvers contains a list of all exported symbols from a kernel
 build.
 
---- 6.1 Symbols From the Kernel (vmlinux + modules)
+--- 6.1 Symbols From the Kernel (vmtronx + modules)
 
 	During a kernel build, a file named Module.symvers will be
 	generated. Module.symvers contains all exported symbols from
@@ -451,7 +451,7 @@ build.
 	would read 0x00000000.
 
 	Module.symvers serves two purposes:
-	1) It lists all exported symbols from vmlinux and all modules.
+	1) It lists all exported symbols from vmtronx and all modules.
 	2) It lists the CRC if CONFIG_MODVERSIONS is enabled.
 
 --- 6.2 Symbols and External Modules
diff --git a/tkernel_source/Documentation/kdump/kdump.txt b/tkernel_source/Documentation/kdump/kdump.txt
index bc4bd5a..014c19a 100644
--- a/tkernel_source/Documentation/kdump/kdump.txt
+++ b/tkernel_source/Documentation/kdump/kdump.txt
@@ -147,7 +147,7 @@ System kernel config options
    CONFIG_DEBUG_INFO=Y
 
    This causes the kernel to be built with debug symbols. The dump
-   analysis tools require a vmlinux with debug symbols in order to read
+   analysis tools require a vmtronx with debug symbols in order to read
    and analyze a dump file.
 
 Dump-capture kernel config options (Arch Independent)
@@ -320,29 +320,29 @@ After booting to the system kernel, dump-capture kernel needs to be
 loaded.
 
 Based on the architecture and type of image (relocatable or not), one
-can choose to load the uncompressed vmlinux or compressed bzImage/vmlinuz
+can choose to load the uncompressed vmtronx or compressed bzImage/vmtronz
 of dump-capture kernel. Following is the summary.
 
 For i386 and x86_64:
-	- Use vmlinux if kernel is not relocatable.
-	- Use bzImage/vmlinuz if kernel is relocatable.
+	- Use vmtronx if kernel is not relocatable.
+	- Use bzImage/vmtronz if kernel is relocatable.
 For ppc64:
-	- Use vmlinux
+	- Use vmtronx
 For ia64:
-	- Use vmlinux or vmlinuz.gz
+	- Use vmtronx or vmtronz.gz
 For s390x:
 	- Use image or bzImage
 For arm:
 	- Use zImage
 
-If you are using a uncompressed vmlinux image then use following command
+If you are using a uncompressed vmtronx image then use following command
 to load dump-capture kernel.
 
-   kexec -p <dump-capture-kernel-vmlinux-image> \
+   kexec -p <dump-capture-kernel-vmtronx-image> \
    --initrd=<initrd-for-dump-capture-kernel> --args-linux \
    --append="root=<root-dev> <arch-specific-options>"
 
-If you are using a compressed bzImage/vmlinuz, then use following command
+If you are using a compressed bzImage/vmtronz, then use following command
 to load dump-capture kernel.
 
    kexec -p <dump-capture-kernel-bzImage> \
@@ -453,10 +453,10 @@ Analysis
 Before analyzing the dump image, you should reboot into a stable kernel.
 
 You can do limited analysis using GDB on the dump file copied out of
-/proc/vmcore. Use the debug vmlinux built with -g and run the following
+/proc/vmcore. Use the debug vmtronx built with -g and run the following
 command:
 
-   gdb vmlinux <dump-file>
+   gdb vmtronx <dump-file>
 
 Stack trace for the task on processor 0, register display, and memory
 display work fine.
diff --git a/tkernel_source/Documentation/kmemcheck.txt b/tkernel_source/Documentation/kmemcheck.txt
index 80aae85..2e2d8b0 100644
--- a/tkernel_source/Documentation/kmemcheck.txt
+++ b/tkernel_source/Documentation/kmemcheck.txt
@@ -264,14 +264,14 @@ the warning.
 If your kernel was compiled with CONFIG_DEBUG_INFO=y, then all we have to do
 is give this address to the addr2line program, like this:
 
-	$ addr2line -e vmlinux -i ffffffff8104ede8
+	$ addr2line -e vmtronx -i ffffffff8104ede8
 	arch/x86/include/asm/string_64.h:12
 	include/asm-generic/siginfo.h:287
 	kernel/signal.c:380
 	kernel/signal.c:410
 
-The "-e vmlinux" tells addr2line which file to look in. IMPORTANT: This must
-be the vmlinux of the kernel that produced the warning in the first place! If
+The "-e vmtronx" tells addr2line which file to look in. IMPORTANT: This must
+be the vmtronx of the kernel that produced the warning in the first place! If
 not, the line number information will almost certainly be wrong.
 
 The "-i" tells addr2line to also print the line numbers of inlined functions.
@@ -341,7 +341,7 @@ kmemcheck stack dump, i.e.:
  [<ffffffff8100b87d>] do_notify_resume+0xad/0x7d0
  [<ffffffff8100c7b5>] int_signal+0x12/0x17
 
-	$ addr2line -e vmlinux -i ffffffff8104f04e ffffffff81050bd8 \
+	$ addr2line -e vmtronx -i ffffffff8104f04e ffffffff81050bd8 \
 		ffffffff8100b87d ffffffff8100c7b5
 	kernel/signal.c:446
 	kernel/signal.c:1806
@@ -494,7 +494,7 @@ that, we'll need the RIP address again:
 
 RIP: 0010:[<ffffffff8104ede8>]  [<ffffffff8104ede8>] __dequeue_signal+0xc8/0x190
 
-	$ objdump -d --no-show-raw-insn vmlinux | grep -C 8 ffffffff8104ede8:
+	$ objdump -d --no-show-raw-insn vmtronx | grep -C 8 ffffffff8104ede8:
 	ffffffff8104edc8:       mov    %r8,0x8(%r8)
 	ffffffff8104edcc:       test   %r10d,%r10d
 	ffffffff8104edcf:       js     ffffffff8104ee88 <__dequeue_signal+0x168>
@@ -544,7 +544,7 @@ initialized. This is the beginning of the struct:
 On 64-bit, the int is 4 bytes long, so it must the union member that has
 not been initialized. We can verify this using gdb:
 
-	$ gdb vmlinux
+	$ gdb vmtronx
 	...
 	(gdb) p &((struct siginfo *) 0)->_sifields
 	$1 = (union {...} *) 0x10
diff --git a/tkernel_source/Documentation/kprobes.txt b/tkernel_source/Documentation/kprobes.txt
index 1f9b3e2..ebcb131 100644
--- a/tkernel_source/Documentation/kprobes.txt
+++ b/tkernel_source/Documentation/kprobes.txt
@@ -318,7 +318,7 @@ kprobe address resolution code.
 
 If you need to insert a probe in the middle of a function, you may find
 it useful to "Compile the kernel with debug info" (CONFIG_DEBUG_INFO),
-so you can use "objdump -d -l vmlinux" to see the source-to-object
+so you can use "objdump -d -l vmtronx" to see the source-to-object
 code mapping.
 
 4. API Reference
diff --git a/tkernel_source/Documentation/module-signing.txt b/tkernel_source/Documentation/module-signing.txt
index c72702e..76a8569 100644
--- a/tkernel_source/Documentation/module-signing.txt
+++ b/tkernel_source/Documentation/module-signing.txt
@@ -106,8 +106,8 @@ keypair using openssl if one does not exist in the files:
 	signing_key.priv
 	signing_key.x509
 
-during the building of vmlinux (the public part of the key needs to be built
-into vmlinux) using parameters in the:
+during the building of vmtronx (the public part of the key needs to be built
+into vmtronx) using parameters in the:
 
 	x509.genkey
 
diff --git a/tkernel_source/Documentation/networking/cxgb.txt b/tkernel_source/Documentation/networking/cxgb.txt
index 20a8876..e39fabe 100644
--- a/tkernel_source/Documentation/networking/cxgb.txt
+++ b/tkernel_source/Documentation/networking/cxgb.txt
@@ -233,7 +233,7 @@ KNOWN ISSUES
           Example using the Grub bootloader:
               title Red Hat Enterprise Linux AS (2.4.21-27.ELsmp)
               root (hd0,0)
-              kernel /vmlinuz-2.4.21-27.ELsmp ro root=/dev/hda3 noirqbalance
+              kernel /vmtronz-2.4.21-27.ELsmp ro root=/dev/hda3 noirqbalance
               initrd /initrd-2.4.21-27.ELsmp.img
 
   2. After running insmod, the driver is loaded and the incorrect network
diff --git a/tkernel_source/Documentation/oops-tracing.txt b/tkernel_source/Documentation/oops-tracing.txt
index f3ac05c..ac1419a 100644
--- a/tkernel_source/Documentation/oops-tracing.txt
+++ b/tkernel_source/Documentation/oops-tracing.txt
@@ -63,7 +63,7 @@ messages ;-)
 Actually, there are things you can do that make this easier. I have two 
 separate approaches:
 
-	gdb /usr/src/linux/vmlinux
+	gdb /usr/src/linux/vmtronx
 	gdb> disassemble <offending_function>
 
 That's the easy way to find the problem, at least if the bug-report is 
diff --git a/tkernel_source/Documentation/power/swsusp-dmcrypt.txt b/tkernel_source/Documentation/power/swsusp-dmcrypt.txt
index 59931b4..69ceb42 100644
--- a/tkernel_source/Documentation/power/swsusp-dmcrypt.txt
+++ b/tkernel_source/Documentation/power/swsusp-dmcrypt.txt
@@ -42,7 +42,7 @@ Prepare your boot loader to use the initrd you will create or
 modify. For lilo the simplest setup looks like the following
 lines:
 
-image=/boot/vmlinuz
+image=/boot/vmtronz
 initrd=/boot/initrd.gz
 label=linux
 append="root=/dev/ram0 init=/linuxrc rw"
diff --git a/tkernel_source/Documentation/powerpc/bootwrapper.txt b/tkernel_source/Documentation/powerpc/bootwrapper.txt
index d60fced..c181161 100644
--- a/tkernel_source/Documentation/powerpc/bootwrapper.txt
+++ b/tkernel_source/Documentation/powerpc/bootwrapper.txt
@@ -2,7 +2,7 @@ The PowerPC boot wrapper
 ------------------------
 Copyright (C) Secret Lab Technologies Ltd.
 
-PowerPC image targets compresses and wraps the kernel image (vmlinux) with
+PowerPC image targets compresses and wraps the kernel image (vmtronx) with
 a boot wrapper to make it usable by the system firmware.  There is no
 standard PowerPC firmware interface, so the boot wrapper is designed to
 be adaptable for each kind of image that needs to be built.
@@ -86,7 +86,7 @@ Currently, the following image format targets exist:
 			tree blob inside the image.
    uImage:		Native image format used by U-Boot.  The uImage target
 			does not add any boot code.  It just wraps a compressed
-			vmlinux in the uImage data structure.  This image
+			vmtronx in the uImage data structure.  This image
 			requires a version of U-Boot that is able to pass
 			a device tree to the kernel at boot.  If using an older
 			version of U-Boot, then you need to use a cuImage
@@ -116,7 +116,7 @@ at the Makefile to see which default image targets are available.
 How it is built
 ---------------
 arch/powerpc is designed to support multiplatform kernels, which means
-that a single vmlinux image can be booted on many different target boards.
+that a single vmtronx image can be booted on many different target boards.
 It also means that the boot wrapper must be able to wrap for many kinds of
 images on a single build.  The design decision was made to not use any
 conditional compilation code (#ifdef, etc) in the boot wrapper source code.
diff --git a/tkernel_source/Documentation/serial/moxa-smartio b/tkernel_source/Documentation/serial/moxa-smartio
index 5d2a33b..e3f51e0 100644
--- a/tkernel_source/Documentation/serial/moxa-smartio
+++ b/tkernel_source/Documentation/serial/moxa-smartio
@@ -359,11 +359,11 @@ Content
 	   c. make dep		     /* take a few minutes */
 	   d. make bzImage	     /* take probably 10-20 minutes */
 	   e. make install	     /* copy boot image to correct position */
-	   f. Please make sure the boot kernel (vmlinuz) is in the
+	   f. Please make sure the boot kernel (vmtronz) is in the
 	      correct position.
 	   g. If you use 'lilo' utility, you should check /etc/lilo.conf
-	      'image' item specified the path which is the 'vmlinuz' path,
-	      or you will load wrong (or old) boot kernel image (vmlinuz).
+	      'image' item specified the path which is the 'vmtronz' path,
+	      or you will load wrong (or old) boot kernel image (vmtronz).
 	      After checking /etc/lilo.conf, please run "lilo".
 
 	  Note that if the result of "make bzImage" is ERROR, then you have to
diff --git a/tkernel_source/Documentation/sh/new-machine.txt b/tkernel_source/Documentation/sh/new-machine.txt
index f035416..c9699ca 100644
--- a/tkernel_source/Documentation/sh/new-machine.txt
+++ b/tkernel_source/Documentation/sh/new-machine.txt
@@ -270,7 +270,7 @@ Architecture specific targets (sh):
 
 which then allows you to do:
 
-$ make ARCH=sh CROSS_COMPILE=sh4-linux- vapor_defconfig vmlinux
+$ make ARCH=sh CROSS_COMPILE=sh4-linux- vapor_defconfig vmtronx
 
 which will in turn copy the defconfig for this board, run it through
 oldconfig (prompting you for any new options since the time of creation),
diff --git a/tkernel_source/Documentation/x86/exception-tables.txt b/tkernel_source/Documentation/x86/exception-tables.txt
index 32901aa..185a345 100644
--- a/tkernel_source/Documentation/x86/exception-tables.txt
+++ b/tkernel_source/Documentation/x86/exception-tables.txt
@@ -156,9 +156,9 @@ memory. But what does the .section stuff do?????
 
 To understand this we have to look at the final kernel:
 
- > objdump --section-headers vmlinux
+ > objdump --section-headers vmtronx
  >
- > vmlinux:     file format elf32-i386
+ > vmtronx:     file format elf32-i386
  >
  > Sections:
  > Idx Name          Size      VMA       LMA       File off  Algn
@@ -183,7 +183,7 @@ There are obviously 2 non standard ELF sections in the generated object
 file. But first we want to find out what happened to our code in the
 final kernel executable:
 
- > objdump --disassemble --section=.text vmlinux
+ > objdump --disassemble --section=.text vmtronx
  >
  > c017e785 <do_con_write+c1> xorl   %edx,%edx
  > c017e787 <do_con_write+c3> movl   0xc01c7bec,%eax
@@ -201,14 +201,14 @@ The instructions bracketed in the .section directives are no longer
 in the normal execution path. They are located in a different section
 of the executable file:
 
- > objdump --disassemble --section=.fixup vmlinux
+ > objdump --disassemble --section=.fixup vmtronx
  >
  > c0199ff5 <.fixup+10b5> movl   $0xfffffff2,%eax
  > c0199ffa <.fixup+10ba> xorb   %dl,%dl
  > c0199ffc <.fixup+10bc> jmp    c017e7a7 <do_con_write+e3>
 
 And finally:
- > objdump --full-contents --section=__ex_table vmlinux
+ > objdump --full-contents --section=__ex_table vmtronx
  >
  >  c01aa7c4 93c017c0 e09f19c0 97c017c0 99c017c0  ................
  >  c01aa7d4 f6c217c0 e99f19c0 a5e717c0 f59f19c0  ................
@@ -239,12 +239,12 @@ are local labels. The local label 1b (1b stands for next label 1
 backward) is the address of the instruction that might fault, i.e.
 in our case the address of the label 1 is c017e7a5:
 the original assembly code: > 1:      movb (%ebx),%dl
-and linked in vmlinux     : > c017e7a5 <do_con_write+e1> movb   (%ebx),%dl
+and linked in vmtronx     : > c017e7a5 <do_con_write+e1> movb   (%ebx),%dl
 
 The local label 3 (backwards again) is the address of the code to handle
 the fault, in our case the actual value is c0199ff5:
 the original assembly code: > 3:      movl $-14,%eax
-and linked in vmlinux     : > c0199ff5 <.fixup+10b5> movl   $0xfffffff2,%eax
+and linked in vmtronx     : > c0199ff5 <.fixup+10b5> movl   $0xfffffff2,%eax
 
 The assembly code
  > .section __ex_table,"a"
diff --git a/tkernel_source/Documentation/zh_CN/basic_profiling.txt b/tkernel_source/Documentation/zh_CN/basic_profiling.txt
index 1e6bf0b..d6406fe 100644
--- a/tkernel_source/Documentation/zh_CN/basic_profiling.txt
+++ b/tkernel_source/Documentation/zh_CN/basic_profiling.txt
@@ -23,10 +23,10 @@ Documentation/basic_profiling的中文翻译
 感谢John Levon,Dave Hansen等在撰写时的帮助
 
 <test> 用于表示要测量的目标
-请先确保您已经有正确的System.map / vmlinux配置!
+请先确保您已经有正确的System.map / vmtronx配置!
 
-对于linux系统来说,配置vmlinuz最容易的方法可能就是使用“make install”,然后修改
-/sbin/installkernel将vmlinux拷贝到/boot目录,而System.map通常是默认安装好的
+对于linux系统来说,配置vmtronz最容易的方法可能就是使用“make install”,然后修改
+/sbin/installkernel将vmtronx拷贝到/boot目录,而System.map通常是默认安装好的
 
 Readprofile
 -----------
@@ -57,7 +57,7 @@ make install
 说明APIC特性没有开启。另外注意idle=poll选项可能有损性能。
 
 One time setup:
-		opcontrol --setup --vmlinux=/boot/vmlinux
+		opcontrol --setup --vmtronx=/boot/vmtronx
 
 clear		opcontrol --reset
 start		opcontrol --start
@@ -65,7 +65,7 @@ start		opcontrol --start
 stop		opcontrol --stop
 dump output	opreport >  output_file
 
-如果只看kernel相关的报告结果,请运行命令 opreport -l /boot/vmlinux > output_file
+如果只看kernel相关的报告结果,请运行命令 opreport -l /boot/vmtronx > output_file
 
 通过reset选项可以清理过期统计数据,相当于重启的效果。
 
diff --git a/tkernel_source/Documentation/zh_CN/oops-tracing.txt b/tkernel_source/Documentation/zh_CN/oops-tracing.txt
index 9312608..1744389 100644
--- a/tkernel_source/Documentation/zh_CN/oops-tracing.txt
+++ b/tkernel_source/Documentation/zh_CN/oops-tracing.txt
@@ -71,7 +71,7 @@ From: Linus Torvalds <torvalds@xxxxxxxx>
 
 实际上,你有办法使它更简单。我有两个不同的方法:
 
-	gdb /usr/src/linux/vmlinux
+	gdb /usr/src/linux/vmtronx
 	gdb> disassemble <offending_function>
 
 那是发现问题的简单办法,至少如果bug报告做的好的情况下(象这个一样-运行ksymoops
diff --git a/tkernel_source/scripts/Makefile b/tkernel_source/scripts/Makefile
index 2016a64..6af4e11 100644
--- a/tkernel_source/scripts/Makefile
+++ b/tkernel_source/scripts/Makefile
@@ -2,7 +2,7 @@
 # scripts contains sources for various helper programs used throughout
 # the kernel for the build process.
 # ---------------------------------------------------------------------------
-# kallsyms:      Find all symbols in vmlinux
+# kallsyms:      Find all symbols in vmtronx
 # pnmttologo:    Convert pnm files to logo files
 # conmakehash:   Create chartable
 # conmakehash:	 Create arrays for initializing the kernel console tables
diff --git a/tkernel_source/scripts/Makefile.lib b/tkernel_source/scripts/Makefile.lib
index 0884873..5a25b6c 100644
--- a/tkernel_source/scripts/Makefile.lib
+++ b/tkernel_source/scripts/Makefile.lib
@@ -267,7 +267,7 @@ cmd_gzip = (cat $(filter-out FORCE,$^) | gzip -n -f -9 > $@) || \
 quiet_cmd_dt_S_dtb= DTB     $@
 cmd_dt_S_dtb=						\
 (							\
-	echo '\#include <asm-generic/vmlinux.lds.h>'; 	\
+	echo '\#include <asm-generic/vmtronx.lds.h>'; 	\
 	echo '.section .dtb.init.rodata,"a"';		\
 	echo '.balign STRUCT_ALIGNMENT';		\
 	echo '.global __dtb_$(*F)_begin';		\
diff --git a/tkernel_source/scripts/Makefile.modpost b/tkernel_source/scripts/Makefile.modpost
index 69f0a14..44fed40 100644
--- a/tkernel_source/scripts/Makefile.modpost
+++ b/tkernel_source/scripts/Makefile.modpost
@@ -82,17 +82,17 @@ modpost = scripts/mod/modpost                    \
 MODPOST_OPT=$(subst -i,-n,$(filter -i,$(MAKEFLAGS)))
 
 # We can go over command line length here, so be careful.
-quiet_cmd_modpost = MODPOST $(words $(filter-out vmlinux FORCE, $^)) modules
+quiet_cmd_modpost = MODPOST $(words $(filter-out vmtronx FORCE, $^)) modules
       cmd_modpost = $(MODLISTCMD) | sed 's/\.ko$$/.o/' | $(modpost) $(MODPOST_OPT) -s -T -
 
 PHONY += __modpost
 __modpost: $(modules:.ko=.o) FORCE
-	$(call cmd,modpost) $(wildcard vmlinux)
+	$(call cmd,modpost) $(wildcard vmtronx)
 
 quiet_cmd_kernel-mod = MODPOST $@
       cmd_kernel-mod = $(modpost) $@
 
-vmlinux.o: FORCE
+vmtronx.o: FORCE
 	$(call cmd,kernel-mod)
 
 # Declare generated files as targets for modpost
diff --git a/tkernel_source/scripts/checkpatch.pl b/tkernel_source/scripts/checkpatch.pl
index c5ec977..4ad278f 100644
--- a/tkernel_source/scripts/checkpatch.pl
+++ b/tkernel_source/scripts/checkpatch.pl
@@ -4306,7 +4306,7 @@ sub process {
 # multi-statement macros should be enclosed in a do while loop, grab the
 # first statement and ensure its the whole macro if its not enclosed
 # in a known good container
-		if ($realfile !~ m@/vmlinux.lds.h$@ &&
+		if ($realfile !~ m@/vmtronx.lds.h$@ &&
 		    $line =~ /^.\s*\#\s*define\s*$Ident(\()?/) {
 			my $ln = $linenr;
 			my $cnt = $realcnt;
@@ -4416,7 +4416,7 @@ sub process {
 # single-statement macros do not need to be enclosed in do while (0) loop,
 # macro should not end with a semicolon
 		if ($^V && $^V ge 5.10.0 &&
-		    $realfile !~ m@/vmlinux.lds.h$@ &&
+		    $realfile !~ m@/vmtronx.lds.h$@ &&
 		    $line =~ /^.\s*\#\s*define\s+$Ident(\()?/) {
 			my $ln = $linenr;
 			my $cnt = $realcnt;
@@ -4469,9 +4469,9 @@ sub process {
 #	.
 #	ALIGN(...)
 #	VMLINUX_SYMBOL(...)
-		if ($realfile eq 'vmlinux.lds.h' && $line =~ /(?:(?:^|\s)$Ident\s*=|=\s*$Ident(?:\s|$))/) {
+		if ($realfile eq 'vmtronx.lds.h' && $line =~ /(?:(?:^|\s)$Ident\s*=|=\s*$Ident(?:\s|$))/) {
 			WARN("MISSING_VMLINUX_SYMBOL",
-			     "vmlinux.lds.h needs VMLINUX_SYMBOL() around C-visible symbols\n" . $herecurr);
+			     "vmtronx.lds.h needs VMLINUX_SYMBOL() around C-visible symbols\n" . $herecurr);
 		}
 
 # check for redundant bracing round if etc
diff --git a/tkernel_source/scripts/checkstack.pl b/tkernel_source/scripts/checkstack.pl
index dd83978..84aa4db 100644
--- a/tkernel_source/scripts/checkstack.pl
+++ b/tkernel_source/scripts/checkstack.pl
@@ -17,7 +17,7 @@
 #	sparc port by Martin Habets <errandir_news@xxxxxxxxxxxxxxxxx>
 #
 #	Usage:
-#	objdump -d vmlinux | scripts/checkstack.pl [arch]
+#	objdump -d vmtronx | scripts/checkstack.pl [arch]
 #
 #	TODO :	Port to all architectures (one regex per arch)
 
diff --git a/tkernel_source/scripts/extract-vmtronx b/tkernel_source/scripts/extract-vmtronx
index 5061abc..36dad61 100644
--- a/tkernel_source/scripts/extract-vmtronx
+++ b/tkernel_source/scripts/extract-vmtronx
@@ -1,6 +1,6 @@
 #!/bin/sh
 # ----------------------------------------------------------------------
-# extract-vmlinux - Extract uncompressed vmlinux from a kernel image
+# extract-vmtronx - Extract uncompressed vmtronx from a kernel image
 #
 # Inspired from extract-ikconfig
 # (c) 2009,2010 Dick Streefland <dick@xxxxxxxxxxxxxx>
@@ -10,10 +10,10 @@
 # Licensed under the GNU General Public License, version 2 (GPLv2).
 # ----------------------------------------------------------------------
 
-check_vmlinux()
+check_vmtronx()
 {
 	# Use readelf to check if it's a valid ELF
-	# TODO: find a better to way to check that it's really vmlinux
+	# TODO: find a better to way to check that it's really vmtronx
 	#       and not just an elf
 	readelf -h $1 > /dev/null 2>&1 || return 1
 
@@ -31,7 +31,7 @@ try_decompress()
 	do
 		pos=${pos%%:*}
 		tail -c+$pos "$img" | $3 > $tmp 2> /dev/null
-		check_vmlinux $tmp
+		check_vmtronx $tmp
 	done
 }
 
@@ -45,11 +45,11 @@ then
 fi
 
 # Prepare temp files:
-tmp=$(mktemp /tmp/vmlinux-XXX)
+tmp=$(mktemp /tmp/vmtronx-XXX)
 trap "rm -f $tmp" 0
 
 # Initial attempt for uncompressed images or objects:
-check_vmlinux $img
+check_vmtronx $img
 
 # That didn't work, so retry after decompression.
 try_decompress '\037\213\010' xy    gunzip
@@ -59,4 +59,4 @@ try_decompress '\135\0\0\0'   xxx   unlzma
 try_decompress '\211\114\132' xy    'lzop -d'
 
 # Bail out:
-echo "$me: Cannot find vmlinux." >&2
+echo "$me: Cannot find vmtronx." >&2
diff --git a/tkernel_source/scripts/kallsyms.c b/tkernel_source/scripts/kallsyms.c
index 8fa81e8..b913eb0 100644
--- a/tkernel_source/scripts/kallsyms.c
+++ b/tkernel_source/scripts/kallsyms.c
@@ -5,7 +5,7 @@
  * This software may be used and distributed according to the terms
  * of the GNU General Public License, incorporated herein by reference.
  *
- * Usage: nm -n vmlinux | scripts/kallsyms [--all-symbols] > symbols.S
+ * Usage: nm -n vmtronx | scripts/kallsyms [--all-symbols] > symbols.S
  *
  *      Table compression uses all the unused char codes on the symbols and
  *  maps these to the most used substrings (tokens). For instance, it might
diff --git a/tkernel_source/scripts/kconfig/streamline_config.pl b/tkernel_source/scripts/kconfig/streamline_config.pl
index f3d3fb4..e6d330b 100644
--- a/tkernel_source/scripts/kconfig/streamline_config.pl
+++ b/tkernel_source/scripts/kconfig/streamline_config.pl
@@ -74,12 +74,12 @@ my @searchconfigs = (
 	    "exec" => "cat",
 	},
 	{
-	    "file" => "/boot/vmlinuz-$uname",
+	    "file" => "/boot/vmtronz-$uname",
 	    "exec" => "scripts/extract-ikconfig",
 	    "test" => "scripts/extract-ikconfig",
 	},
 	{
-	    "file" => "vmlinux",
+	    "file" => "vmtronx",
 	    "exec" => "scripts/extract-ikconfig",
 	    "test" => "scripts/extract-ikconfig",
 	},
diff --git a/tkernel_source/scripts/markup_oops.pl b/tkernel_source/scripts/markup_oops.pl
index c21d163..5c8b758 100644
--- a/tkernel_source/scripts/markup_oops.pl
+++ b/tkernel_source/scripts/markup_oops.pl
@@ -17,7 +17,7 @@ use Getopt::Long;
 
 
 my $cross_compile = "";
-my $vmlinux_name = "";
+my $vmtronx_name = "";
 my $modulefile = "";
 
 # Get options
@@ -26,14 +26,14 @@ Getopt::Long::GetOptions(
 	'module|m=s'		=> \$modulefile,
 	'help|h'		=> \&usage,
 ) || usage ();
-my $vmlinux_name = $ARGV[0];
-if (!defined($vmlinux_name)) {
+my $vmtronx_name = $ARGV[0];
+if (!defined($vmtronx_name)) {
 	my $kerver = `uname -r`;
 	chomp($kerver);
-	$vmlinux_name = "/lib/modules/$kerver/build/vmlinux";
-	print "No vmlinux specified, assuming $vmlinux_name\n";
+	$vmtronx_name = "/lib/modules/$kerver/build/vmtronx";
+	print "No vmtronx specified, assuming $vmtronx_name\n";
 }
-my $filename = $vmlinux_name;
+my $filename = $vmtronx_name;
 
 # Parse the oops to find the EIP value
 
diff --git a/tkernel_source/scripts/mksysmap b/tkernel_source/scripts/mksysmap
index 7ada35a..b84f89f 100644
--- a/tkernel_source/scripts/mksysmap
+++ b/tkernel_source/scripts/mksysmap
@@ -1,10 +1,10 @@
 #!/bin/sh -x
-# Based on the vmlinux file create the System.map file
+# Based on the vmtronx file create the System.map file
 # System.map is used by module-init tools and some debugging
 # tools to retrieve the actual addresses of symbols in the kernel.
 #
 # Usage
-# mksysmap vmlinux System.map
+# mksysmap vmtronx System.map
 
 
 #####
diff --git a/tkernel_source/scripts/package/builddeb b/tkernel_source/scripts/package/builddeb
index 88dbf23..a23d4cb 100644
--- a/tkernel_source/scripts/package/builddeb
+++ b/tkernel_source/scripts/package/builddeb
@@ -99,10 +99,10 @@ um)
 	installed_image_path="usr/bin/linux-$version"
 	;;
 parisc|mips|powerpc)
-	installed_image_path="boot/vmlinux-$version"
+	installed_image_path="boot/vmtronx-$version"
 	;;
 *)
-	installed_image_path="boot/vmlinuz-$version"
+	installed_image_path="boot/vmtronz-$version"
 esac
 
 BUILD_DEBUG="$(grep -s '^CONFIG_DEBUG_INFO=y' $KCONFIG_CONFIG || true)"
@@ -362,12 +362,12 @@ if [ -n "$BUILD_DEBUG" ] ; then
 	# Different tools want the image in different locations
 	# perf
 	mkdir -p $dbg_dir/usr/lib/debug/lib/modules/$version/
-	cp vmlinux $dbg_dir/usr/lib/debug/lib/modules/$version/
+	cp vmtronx $dbg_dir/usr/lib/debug/lib/modules/$version/
 	# systemtap
 	mkdir -p $dbg_dir/usr/lib/debug/boot/
-	ln -s ../lib/modules/$version/vmlinux $dbg_dir/usr/lib/debug/boot/vmlinux-$version
+	ln -s ../lib/modules/$version/vmtronx $dbg_dir/usr/lib/debug/boot/vmtronx-$version
 	# kdump-tools
-	ln -s lib/modules/$version/vmlinux $dbg_dir/usr/lib/debug/vmlinux-$version
+	ln -s lib/modules/$version/vmtronx $dbg_dir/usr/lib/debug/vmtronx-$version
 
 	cat <<EOF >> debian/control
 
diff --git a/tkernel_source/scripts/package/buildtar b/tkernel_source/scripts/package/buildtar
index e046bff..8309edf 100644
--- a/tkernel_source/scripts/package/buildtar
+++ b/tkernel_source/scripts/package/buildtar
@@ -66,7 +66,7 @@ fi
 #
 cp -v -- "${objtree}/System.map" "${tmpdir}/boot/System.map-${KERNELRELEASE}"
 cp -v -- "${objtree}/.config" "${tmpdir}/boot/config-${KERNELRELEASE}"
-cp -v -- "${objtree}/vmlinux" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
+cp -v -- "${objtree}/vmtronx" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
 
 
 #
@@ -74,42 +74,42 @@ cp -v -- "${objtree}/vmlinux" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
 #
 case "${ARCH}" in
 	x86|i386|x86_64)
-		[ -f "${objtree}/arch/x86/boot/bzImage" ] && cp -v -- "${objtree}/arch/x86/boot/bzImage" "${tmpdir}/boot/vmlinuz-${KERNELRELEASE}"
+		[ -f "${objtree}/arch/x86/boot/bzImage" ] && cp -v -- "${objtree}/arch/x86/boot/bzImage" "${tmpdir}/boot/vmtronz-${KERNELRELEASE}"
 		;;
 	alpha)
-		[ -f "${objtree}/arch/alpha/boot/vmlinux.gz" ] && cp -v -- "${objtree}/arch/alpha/boot/vmlinux.gz" "${tmpdir}/boot/vmlinuz-${KERNELRELEASE}"
+		[ -f "${objtree}/arch/alpha/boot/vmtronx.gz" ] && cp -v -- "${objtree}/arch/alpha/boot/vmtronx.gz" "${tmpdir}/boot/vmtronz-${KERNELRELEASE}"
 		;;
 	parisc*)
-		[ -f "${KBUILD_IMAGE}" ] && cp -v -- "${KBUILD_IMAGE}" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
+		[ -f "${KBUILD_IMAGE}" ] && cp -v -- "${KBUILD_IMAGE}" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
 		[ -f "${objtree}/lifimage" ] && cp -v -- "${objtree}/lifimage" "${tmpdir}/boot/lifimage-${KERNELRELEASE}"
 		;;
 	vax)
-		[ -f "${objtree}/vmlinux.SYS" ] && cp -v -- "${objtree}/vmlinux.SYS" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}.SYS"
-		[ -f "${objtree}/vmlinux.dsk" ] && cp -v -- "${objtree}/vmlinux.dsk" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}.dsk"
+		[ -f "${objtree}/vmtronx.SYS" ] && cp -v -- "${objtree}/vmtronx.SYS" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}.SYS"
+		[ -f "${objtree}/vmtronx.dsk" ] && cp -v -- "${objtree}/vmtronx.dsk" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}.dsk"
 		;;
 	mips)
-		if [ -f "${objtree}/arch/mips/boot/compressed/vmlinux.bin" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/compressed/vmlinux.bin" "${tmpdir}/boot/vmlinuz-${KERNELRELEASE}"
-		elif [ -f "${objtree}/arch/mips/boot/compressed/vmlinux.ecoff" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/compressed/vmlinux.ecoff" "${tmpdir}/boot/vmlinuz-${KERNELRELEASE}"
-		elif [ -f "${objtree}/arch/mips/boot/compressed/vmlinux.srec" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/compressed/vmlinux.srec" "${tmpdir}/boot/vmlinuz-${KERNELRELEASE}"
-		elif [ -f "${objtree}/vmlinux.32" ]; then
-			cp -v -- "${objtree}/vmlinux.32" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
-		elif [ -f "${objtree}/vmlinux.64" ]; then
-			cp -v -- "${objtree}/vmlinux.64" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
-		elif [ -f "${objtree}/arch/mips/boot/vmlinux.bin" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/vmlinux.bin" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
-		elif [ -f "${objtree}/arch/mips/boot/vmlinux.ecoff" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/vmlinux.ecoff" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
-		elif [ -f "${objtree}/arch/mips/boot/vmlinux.srec" ]; then
-			cp -v -- "${objtree}/arch/mips/boot/vmlinux.srec" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
-		elif [ -f "${objtree}/vmlinux" ]; then
-			cp -v -- "${objtree}/vmlinux" "${tmpdir}/boot/vmlinux-${KERNELRELEASE}"
+		if [ -f "${objtree}/arch/mips/boot/compressed/vmtronx.bin" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/compressed/vmtronx.bin" "${tmpdir}/boot/vmtronz-${KERNELRELEASE}"
+		elif [ -f "${objtree}/arch/mips/boot/compressed/vmtronx.ecoff" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/compressed/vmtronx.ecoff" "${tmpdir}/boot/vmtronz-${KERNELRELEASE}"
+		elif [ -f "${objtree}/arch/mips/boot/compressed/vmtronx.srec" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/compressed/vmtronx.srec" "${tmpdir}/boot/vmtronz-${KERNELRELEASE}"
+		elif [ -f "${objtree}/vmtronx.32" ]; then
+			cp -v -- "${objtree}/vmtronx.32" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
+		elif [ -f "${objtree}/vmtronx.64" ]; then
+			cp -v -- "${objtree}/vmtronx.64" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
+		elif [ -f "${objtree}/arch/mips/boot/vmtronx.bin" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/vmtronx.bin" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
+		elif [ -f "${objtree}/arch/mips/boot/vmtronx.ecoff" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/vmtronx.ecoff" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
+		elif [ -f "${objtree}/arch/mips/boot/vmtronx.srec" ]; then
+			cp -v -- "${objtree}/arch/mips/boot/vmtronx.srec" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
+		elif [ -f "${objtree}/vmtronx" ]; then
+			cp -v -- "${objtree}/vmtronx" "${tmpdir}/boot/vmtronx-${KERNELRELEASE}"
 		fi
 		;;
 	*)
-		[ -f "${KBUILD_IMAGE}" ] && cp -v -- "${KBUILD_IMAGE}" "${tmpdir}/boot/vmlinux-kbuild-${KERNELRELEASE}"
+		[ -f "${KBUILD_IMAGE}" ] && cp -v -- "${KBUILD_IMAGE}" "${tmpdir}/boot/vmtronx-kbuild-${KERNELRELEASE}"
 		echo "" >&2
 		echo '** ** **  WARNING  ** ** **' >&2
 		echo "" >&2
diff --git a/tkernel_source/scripts/package/mkspec b/tkernel_source/scripts/package/mkspec
index d9ab94b..88ff76b 100644
--- a/tkernel_source/scripts/package/mkspec
+++ b/tkernel_source/scripts/package/mkspec
@@ -94,14 +94,14 @@ echo 'INSTALL_MOD_PATH=$RPM_BUILD_ROOT make %{?_smp_mflags} KBUILD_SRC= mod-fw=
 echo 'INSTALL_FW_PATH=$RPM_BUILD_ROOT'"/lib/firmware/$KERNELRELEASE"
 echo 'make INSTALL_FW_PATH=$INSTALL_FW_PATH' firmware_install
 echo "%ifarch ia64"
-echo 'cp $KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/efi/vmlinuz-$KERNELRELEASE"
-echo 'ln -s '"efi/vmlinuz-$KERNELRELEASE" '$RPM_BUILD_ROOT'"/boot/"
+echo 'cp $KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/efi/vmtronz-$KERNELRELEASE"
+echo 'ln -s '"efi/vmtronz-$KERNELRELEASE" '$RPM_BUILD_ROOT'"/boot/"
 echo "%else"
 echo "%ifarch ppc64"
-echo "cp vmlinux arch/powerpc/boot"
-echo "cp arch/powerpc/boot/"'$KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/vmlinuz-$KERNELRELEASE"
+echo "cp vmtronx arch/powerpc/boot"
+echo "cp arch/powerpc/boot/"'$KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/vmtronz-$KERNELRELEASE"
 echo "%else"
-echo 'cp $KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/vmlinuz-$KERNELRELEASE"
+echo 'cp $KBUILD_IMAGE $RPM_BUILD_ROOT'"/boot/vmtronz-$KERNELRELEASE"
 echo "%endif"
 echo "%endif"
 
@@ -111,16 +111,16 @@ echo 'cp System.map $RPM_BUILD_ROOT'"/boot/System.map-$KERNELRELEASE"
 echo 'cp .config $RPM_BUILD_ROOT'"/boot/config-$KERNELRELEASE"
 
 echo "%ifnarch ppc64"
-echo 'cp vmlinux vmlinux.orig'
-echo 'bzip2 -9 vmlinux'
-echo 'mv vmlinux.bz2 $RPM_BUILD_ROOT'"/boot/vmlinux-$KERNELRELEASE.bz2"
-echo 'mv vmlinux.orig vmlinux'
+echo 'cp vmtronx vmtronx.orig'
+echo 'bzip2 -9 vmtronx'
+echo 'mv vmtronx.bz2 $RPM_BUILD_ROOT'"/boot/vmtronx-$KERNELRELEASE.bz2"
+echo 'mv vmtronx.orig vmtronx'
 echo "%endif"
 
 if ! $PREBUILT; then
 echo 'rm -f $RPM_BUILD_ROOT'"/lib/modules/$KERNELRELEASE/{build,source}"
 echo "mkdir -p "'$RPM_BUILD_ROOT'"/usr/src/kernels/$KERNELRELEASE"
-echo "EXCLUDES=\"$RCS_TAR_IGNORE --exclude .tmp_versions --exclude=*vmlinux* --exclude=*.o --exclude=*.ko --exclude=*.cmd --exclude=Documentation --exclude=firmware --exclude .config.old --exclude .missing-syscalls.d\""
+echo "EXCLUDES=\"$RCS_TAR_IGNORE --exclude .tmp_versions --exclude=*vmtronx* --exclude=*.o --exclude=*.ko --exclude=*.cmd --exclude=Documentation --exclude=firmware --exclude .config.old --exclude .missing-syscalls.d\""
 echo "tar "'$EXCLUDES'" -cf- . | (cd "'$RPM_BUILD_ROOT'"/usr/src/kernels/$KERNELRELEASE;tar xvf -)"
 echo 'cd $RPM_BUILD_ROOT'"/lib/modules/$KERNELRELEASE"
 echo "ln -sf /usr/src/kernels/$KERNELRELEASE build"
@@ -132,12 +132,12 @@ echo "%clean"
 echo 'rm -rf $RPM_BUILD_ROOT'
 echo ""
 echo "%post"
-echo "if [ -x /sbin/installkernel -a -r /boot/vmlinuz-$KERNELRELEASE -a -r /boot/System.map-$KERNELRELEASE ]; then"
-echo "cp /boot/vmlinuz-$KERNELRELEASE /boot/vmlinuz-$KERNELRELEASE-rpm"
+echo "if [ -x /sbin/installkernel -a -r /boot/vmtronz-$KERNELRELEASE -a -r /boot/System.map-$KERNELRELEASE ]; then"
+echo "cp /boot/vmtronz-$KERNELRELEASE /boot/vmtronz-$KERNELRELEASE-rpm"
 echo "cp /boot/System.map-$KERNELRELEASE /boot/System.map-$KERNELRELEASE-rpm"
-echo "rm -f /boot/vmlinuz-$KERNELRELEASE /boot/System.map-$KERNELRELEASE"
-echo "/sbin/installkernel $KERNELRELEASE /boot/vmlinuz-$KERNELRELEASE-rpm /boot/System.map-$KERNELRELEASE-rpm"
-echo "rm -f /boot/vmlinuz-$KERNELRELEASE-rpm /boot/System.map-$KERNELRELEASE-rpm"
+echo "rm -f /boot/vmtronz-$KERNELRELEASE /boot/System.map-$KERNELRELEASE"
+echo "/sbin/installkernel $KERNELRELEASE /boot/vmtronz-$KERNELRELEASE-rpm /boot/System.map-$KERNELRELEASE-rpm"
+echo "rm -f /boot/vmtronz-$KERNELRELEASE-rpm /boot/System.map-$KERNELRELEASE-rpm"
 echo "fi"
 echo ""
 echo "%files"
diff --git a/tkernel_source/scripts/recordmcount.pl b/tkernel_source/scripts/recordmcount.pl
index 96e2486..6559d98 100644
--- a/tkernel_source/scripts/recordmcount.pl
+++ b/tkernel_source/scripts/recordmcount.pl
@@ -8,7 +8,7 @@
 #
 # What we want to end up with this is that each object file will have a
 # section called __mcount_loc that will hold the list of pointers to mcount
-# callers. After final linking, the vmlinux will have within .init.data the
+# callers. After final linking, the vmtronx will have within .init.data the
 # list of all callers to mcount between __start_mcount_loc and __stop_mcount_loc.
 # Later on boot up, the kernel will read this list, save the locations and turn
 # them into nops. When tracing or profiling is later enabled, these locations
diff --git a/tkernel_source/sysdepend/arm/Makefile.linux b/tkernel_source/sysdepend/arm/Makefile.linux
index 4165592..dc4f665 100644
--- a/tkernel_source/sysdepend/arm/Makefile.linux
+++ b/tkernel_source/sysdepend/arm/Makefile.linux
@@ -13,9 +13,9 @@
 # Ensure linker flags are correct
 LDFLAGS		:=
 
-LDFLAGS_vmlinux	:=-p --no-undefined -X --pic-veneer
+LDFLAGS_vmtronx	:=-p --no-undefined -X --pic-veneer
 ifeq ($(CONFIG_CPU_ENDIAN_BE8),y)
-LDFLAGS_vmlinux	+= --be8
+LDFLAGS_vmtronx	+= --be8
 LDFLAGS_MODULE	+= --be8
 endif
 
@@ -253,7 +253,7 @@ INSTALL_TARGETS	= zinstall uinstall install
 
 PHONY += bzImage $(BOOT_TARGETS) $(INSTALL_TARGETS)
 
-$(BOOT_TARGETS): vmlinux
+$(BOOT_TARGETS): vmtronx
 	$(Q)$(MAKE) $(build)=$(boot) MACHINE=$(MACHINE) $(boot)/$@
 
 $(INSTALL_TARGETS):
diff --git a/tkernel_source/scripts/decode_stacktrace.sh b/tkernel_source/scripts/decode_stacktrace.sh
index 515c4c0..3207e7a 100644
--- a/tkernel_source/scripts/decode_stacktrace.sh
+++ b/tkernel_source/scripts/decode_stacktrace.sh
@@ -4,11 +4,11 @@
 
 if [[ $# != 2 ]]; then
 	echo "Usage:"
-	echo "	$0 [vmlinux] [base path]"
+	echo "	$0 [vmtronx] [base path]"
 	exit 1
 fi
 
-vmlinux=$1
+vmtronx=$1
 basepath=$2
 declare -A cache
 
@@ -23,13 +23,13 @@ parse_symbol() {
 	# Strip the symbol name so that we could look it up
 	local name=${symbol%+*}
 
 	# Use 'nm vmlinux' to figure out the base address of said symbol.
 	# It's actually faster to call it every time than to load it
 	# all into bash.
 	if [[ "${cache[$name]+isset}" == "isset" ]]; then
 		local base_addr=${cache[$name]}
 	else
-		local base_addr=$(nm "$vmlinux" | grep -i ' t ' | awk "/ $name\$/ {print \$1}" | head -n1)
+		local base_addr=$(nm "$vmtronx" | grep -i ' t ' | awk "/ $name\$/ {print \$1}" | head -n1)
 		cache["$name"]="$base_addr"
 	fi
 	# Let's start doing the math to get the exact address into the
@@ -49,7 +49,7 @@ parse_symbol() {
 	if [[ "${cache[$address]+isset}" == "isset" ]]; then
 		local code=${cache[$address]}
 	else
-		local code=$(addr2line -i -e "$vmlinux" "$address")
+		local code=$(addr2line -i -e "$vmtronx" "$address")
 		cache[$address]=$code
 	fi
 
@@ -23,13 +23,13 @@ parse_symbol() {
 	local name=${symbol%+*}
 
-	# Use 'nm vmlinux' to figure out the base address of said symbol.
+	# Use 'nm vmtronx' to figure out the base address of said symbol.
 	# It's actually faster to call it every time than to load it
 	# all into bash.
diff --git a/tkernel_source/scripts/gdb/linux/symbols.py b/tkernel_source/scripts/gdb/linux/symbols.py
index cd5bea9..91adf79 100644
--- a/tkernel_source/scripts/gdb/linux/symbols.py
+++ b/tkernel_source/scripts/gdb/linux/symbols.py
@@ -57,7 +57,7 @@ if hasattr(gdb, 'Breakpoint'):
 class LxSymbols(gdb.Command):
     """(Re-)load symbols of Linux kernel and currently loaded modules.
 
-The kernel (vmlinux) is taken from the current working directly. Modules (.ko)
+The kernel (vmtronx) is taken from the current working directly. Modules (.ko)
 are scanned recursively, starting in the same directory. Optionally, the module
 search path can be extended by a space separated list of paths passed to the
 lx-symbols command."""
@@ -130,7 +130,7 @@ lx-symbols command."""
             gdb.write("no module object found for '{0}'\n".format(module_name))
 
     def load_all_symbols(self):
-        gdb.write("loading vmlinux\n")
+        gdb.write("loading vmtronx\n")
 
         # Dropping symbols will disable all breakpoints. So save their states
         # and restore them afterward.
@@ -139,9 +139,9 @@ lx-symbols command."""
             for bp in gdb.breakpoints():
                 saved_states.append({'breakpoint': bp, 'enabled': bp.enabled})
 
         # drop all current symbols and reload vmlinux
         gdb.execute("symbol-file", to_string=True)
-        gdb.execute("symbol-file vmlinux")
+        gdb.execute("symbol-file vmtronx")
 
         self.loaded_modules = []
         module_list = modules.module_list()
@@ -139,9 +139,9 @@ lx-symbols command."""
                 saved_states.append({'breakpoint': bp, 'enabled': bp.enabled})
 
-        # drop all current symbols and reload vmlinux
+        # drop all current symbols and reload vmtronx
         gdb.execute("symbol-file", to_string=True)
diff --git a/tkernel_source/scripts/link-vmtronx.sh b/tkernel_source/scripts/link-vmtronx.sh
index 39dfbd0..b726029 100644
--- a/tkernel_source/scripts/link-vmtronx.sh
+++ b/tkernel_source/scripts/link-vmtronx.sh
@@ -1,13 +1,13 @@
 #!/bin/sh
 #
-# link vmlinux
+# link vmtronx
 #
 # vmlinux is linked from the objects selected by $(KBUILD_VMLINUX_INIT) and
 # $(KBUILD_VMLINUX_MAIN). Most are built-in.o files from top-level directories
 # in the kernel tree, others are specified in arch/$(ARCH)/Makefile.
 # Ordering when linking is important, and $(KBUILD_VMLINUX_INIT) must be first.
 #
-# vmlinux
+# vmtronx
 #   ^
 #   |
 #   +-< $(KBUILD_VMLINUX_INIT)
@@ -18,10 +18,10 @@
 #   |
 #   +-< ${kallsymso} (see description in KALLSYMS section)
 #
-# vmlinux version (uname -v) cannot be updated during normal
+# vmtronx version (uname -v) cannot be updated during normal
 # descending-into-subdirs phase since we do not yet know if we need to
 # update vmlinux.
 # Therefore this step is delayed until just before final link of vmlinux.
 #
 # System.map is generated to document addresses of all kernel symbols
 
@@ -37,7 +37,7 @@ info()
 	fi
 }
 
 # Link of vmlinux.o used for section mismatch analysis
 # ${1} output file
 modpost_link()
 {
@@ -45,19 +45,19 @@ modpost_link()
 		--start-group ${KBUILD_VMLINUX_MAIN} --end-group
 }
 
 # Link of vmlinux
 # ${1} - optional extra .o files
 # ${2} - output file
-vmlinux_link()
+vmtronx_link()
 {
 	local lds="${objtree}/${KBUILD_LDS}"
 
 	if [ "${SRCARCH}" != "um" ]; then
-		${LD} ${LDFLAGS} ${LDFLAGS_vmlinux} -o ${2}                  \
+		${LD} ${LDFLAGS} ${LDFLAGS_vmtronx} -o ${2}                  \
 			-T ${lds} ${KBUILD_VMLINUX_INIT}                     \
 			--start-group ${KBUILD_VMLINUX_MAIN} --end-group ${1}
 	else
-		${CC} ${CFLAGS_vmlinux} -o ${2}                              \
+		${CC} ${CFLAGS_vmtronx} -o ${2}                              \
 			-Wl,-T,${lds} ${KBUILD_VMLINUX_INIT}                 \
 			-Wl,--start-group                                    \
 				 ${KBUILD_VMLINUX_MAIN}                      \
@@ -118,10 +118,10 @@ cleanup()
 	rm -f .tmp_System.map
 	rm -f .tmp_kallsyms*
 	rm -f .tmp_version
-	rm -f .tmp_vmlinux*
+	rm -f .tmp_vmtronx*
 	rm -f System.map
-	rm -f vmlinux
-	rm -f vmlinux.o
+	rm -f vmtronx
+	rm -f vmtronx.o
 }
 
 #
@@ -148,12 +148,12 @@ case "${KCONFIG_CONFIG}" in
 	. "./${KCONFIG_CONFIG}"
 esac
 
-#link vmlinux.o
-info LD vmlinux.o
-modpost_link vmlinux.o
+#link vmtronx.o
+info LD vmtronx.o
+modpost_link vmtronx.o
 
-# modpost vmlinux.o to check for section mismatches
-${MAKE} -f "${srctree}/scripts/Makefile.modpost" vmlinux.o
+# modpost vmtronx.o to check for section mismatches
+${MAKE} -f "${srctree}/scripts/Makefile.modpost" vmtronx.o
 
 # Update version
 info GEN .version
@@ -169,64 +169,64 @@ fi;
 ${MAKE} -f "${srctree}/scripts/Makefile.build" obj=kernel/sysinit
 
 kallsymso=""
-kallsyms_vmlinux=""
+kallsyms_vmtronx=""
 if [ -n "${CONFIG_KALLSYMS}" ]; then
 
 	# kallsyms support
 	# Generate section listing all symbols and add it into vmlinux
 	# It's a three step process:
 	# 1)  Link .tmp_vmlinux1 so it has all symbols and sections,
 	#     but __kallsyms is empty.
 	#     Running kallsyms on that gives us .tmp_kallsyms1.o with
 	#     the right size
 	# 2)  Link .tmp_vmlinux2 so it now has a __kallsyms section of
 	#     the right size, but due to the added section, some
 	#     addresses have shifted.
 	#     From here, we generate a correct .tmp_kallsyms2.o
 	# 2a) We may use an extra pass as this has been necessary to
 	#     woraround some alignment related bugs.
 	#     KALLSYMS_EXTRA_PASS=1 is used to trigger this.
 	# 3)  The correct ${kallsymso} is linked into the final vmlinux.
 	#
 	# a)  Verify that the System.map from vmlinux matches the map from
 	#     ${kallsymso}.
 
 	kallsymso=.tmp_kallsyms2.o
-	kallsyms_vmlinux=.tmp_vmlinux2
+	kallsyms_vmtronx=.tmp_vmtronx2
 
 	# step 1
-	vmlinux_link "" .tmp_vmlinux1
-	kallsyms .tmp_vmlinux1 .tmp_kallsyms1.o
+	vmtronx_link "" .tmp_vmtronx1
+	kallsyms .tmp_vmtronx1 .tmp_kallsyms1.o
 
 	# step 2
-	vmlinux_link .tmp_kallsyms1.o .tmp_vmlinux2
-	kallsyms .tmp_vmlinux2 .tmp_kallsyms2.o
+	vmtronx_link .tmp_kallsyms1.o .tmp_vmtronx2
+	kallsyms .tmp_vmtronx2 .tmp_kallsyms2.o
 
 	# step 2a
 	if [ -n "${KALLSYMS_EXTRA_PASS}" ]; then
 		kallsymso=.tmp_kallsyms3.o
-		kallsyms_vmlinux=.tmp_vmlinux3
+		kallsyms_vmtronx=.tmp_vmtronx3
 
-		vmlinux_link .tmp_kallsyms2.o .tmp_vmlinux3
+		vmtronx_link .tmp_kallsyms2.o .tmp_vmtronx3
 
-		kallsyms .tmp_vmlinux3 .tmp_kallsyms3.o
+		kallsyms .tmp_vmtronx3 .tmp_kallsyms3.o
 	fi
 fi
 
-info LD vmlinux
-vmlinux_link "${kallsymso}" vmlinux
+info LD vmtronx
+vmtronx_link "${kallsymso}" vmtronx
 
 if [ -n "${CONFIG_BUILDTIME_EXTABLE_SORT}" ]; then
-	info SORTEX vmlinux
-	sortextable vmlinux
+	info SORTEX vmtronx
+	sortextable vmtronx
 fi
 
 info SYSMAP System.map
-mksysmap vmlinux System.map
+mksysmap vmtronx System.map
 
 # step a (see comment above)
 if [ -n "${CONFIG_KALLSYMS}" ]; then
-	mksysmap ${kallsyms_vmlinux} .tmp_System.map
+	mksysmap ${kallsyms_vmtronx} .tmp_System.map
 
 	if ! cmp -s System.map .tmp_System.map; then
 		echo >&2 Inconsistent kallsyms data
@@ -1,13 +1,13 @@
 #
-# vmlinux is linked from the objects selected by $(KBUILD_VMLINUX_INIT) and
+# vmtronx is linked from the objects selected by $(KBUILD_VMLINUX_INIT) and
 # $(KBUILD_VMLINUX_MAIN). Most are built-in.o files from top-level directories
 # in the kernel tree, others are specified in arch/$(ARCH)/Makefile.
@@ -18,10 +18,10 @@
 # descending-into-subdirs phase since we do not yet know if we need to
-# update vmlinux.
-# Therefore this step is delayed until just before final link of vmlinux.
+# update vmtronx.
+# Therefore this step is delayed until just before final link of vmtronx.
 #
 # System.map is generated to document addresses of all kernel symbols
@@ -37,7 +37,7 @@ info()
 }
 
-# Link of vmlinux.o used for section mismatch analysis
+# Link of vmtronx.o used for section mismatch analysis
 # ${1} output file
 modpost_link()
@@ -45,19 +45,19 @@ modpost_link()
 }
 
-# Link of vmlinux
+# Link of vmtronx
 # ${1} - optional extra .o files
 # ${2} - output file
@@ -169,64 +169,64 @@ fi;
 
 	# kallsyms support
-	# Generate section listing all symbols and add it into vmlinux
+	# Generate section listing all symbols and add it into vmtronx
 	# It's a three step process:
@@ -169,64 +169,64 @@ fi;
 	# It's a three step process:
-	# 1)  Link .tmp_vmlinux1 so it has all symbols and sections,
+	# 1)  Link .tmp_vmtronx1 so it has all symbols and sections,
 	#     but __kallsyms is empty.
 	#     Running kallsyms on that gives us .tmp_kallsyms1.o with
@@ -169,64 +169,64 @@ fi;
 	#     Running kallsyms on that gives us .tmp_kallsyms1.o with
 	#     the right size
-	# 2)  Link .tmp_vmlinux2 so it now has a __kallsyms section of
+	# 2)  Link .tmp_vmtronx2 so it now has a __kallsyms section of
 	#     the right size, but due to the added section, some
 	#     addresses have shifted.
@@ -169,64 +169,64 @@ fi;
 	#     woraround some alignment related bugs.
 	#     KALLSYMS_EXTRA_PASS=1 is used to trigger this.
-	# 3)  The correct ${kallsymso} is linked into the final vmlinux.
+	# 3)  The correct ${kallsymso} is linked into the final vmtronx.
 	#
@@ -169,64 +169,64 @@ fi;
 	#
-	# a)  Verify that the System.map from vmlinux matches the map from
+	# a)  Verify that the System.map from vmtronx matches the map from
 	#     ${kallsymso}.
 
diff --git a/tkernel_source/scripts/mod/modpost.c b/tkernel_source/scripts/mod/modpost.c
index 91ee1b2..4033a10 100644
--- a/tkernel_source/scripts/mod/modpost.c
+++ b/tkernel_source/scripts/mod/modpost.c
@@ -8,7 +8,7 @@
  * This software may be used and distributed according to the terms
  * of the GNU General Public License, incorporated herein by reference.
  *
  * Usage: modpost vmlinux module1.o module2.o ...
  */
 
 #define _GNU_SOURCE
@@ -25,14 +25,14 @@
 
 /* Are we using CONFIG_MODVERSIONS? */
 static int modversions = 0;
-/* Warn about undefined symbols? (do so if we have vmlinux) */
-static int have_vmlinux = 0;
+/* Warn about undefined symbols? (do so if we have vmtronx) */
+static int have_vmtronx = 0;
 /* Is CONFIG_MODULE_SRCVERSION_ALL set? */
 static int all_versions = 0;
 /* If we are modposting external module set to 1 */
 static int external_module = 0;
-/* Warn about section mismatch in vmlinux if set to 1 */
-static int vmlinux_section_warnings = 1;
+/* Warn about section mismatch in vmtronx if set to 1 */
+static int vmtronx_section_warnings = 1;
 /* Only warn about unresolved symbols */
 static int warn_unresolved = 0;
 /* How a symbol is exported */
@@ -91,7 +91,7 @@ static inline bool strends(const char *str, const char *postfix)
 	return strcmp(str + strlen(str) - strlen(postfix), postfix) == 0;
 }
 
-static int is_vmlinux(const char *modname)
+static int is_vmtronx(const char *modname)
 {
 	const char *myname;
 
@@ -101,8 +101,8 @@ static int is_vmlinux(const char *modname)
 	else
 		myname = modname;
 
-	return (strcmp(myname, "vmlinux") == 0) ||
-	       (strcmp(myname, "vmlinux.o") == 0);
+	return (strcmp(myname, "vmtronx") == 0) ||
+	       (strcmp(myname, "vmtronx.o") == 0);
 }
 
 void *do_nofail(void *ptr, const char *expr)
@@ -161,7 +161,7 @@ struct symbol {
 	unsigned int crc;
 	int crc_valid;
 	unsigned int weak:1;
-	unsigned int vmlinux:1;    /* 1 if symbol is defined in vmlinux */
+	unsigned int vmtronx:1;    /* 1 if symbol is defined in vmtronx */
 	unsigned int kernel:1;     /* 1 if symbol is from kernel
 				    *  (only for external modules) **/
 	unsigned int preloaded:1;  /* 1 if symbol from Module.symvers, or crc */
@@ -314,14 +314,14 @@ static struct symbol *sym_add_exported(const char *name, struct module *mod,
 			warn("%s: '%s' exported twice. Previous export "
 			     "was in %s%s\n", mod->name, name,
 			     s->module->name,
-			     is_vmlinux(s->module->name) ?"":".ko");
+			     is_vmtronx(s->module->name) ?"":".ko");
 		} else {
 			/* In case Module.symvers was out of date */
 			s->module = mod;
 		}
 	}
 	s->preloaded = 0;
-	s->vmlinux   = is_vmlinux(mod->name);
+	s->vmtronx   = is_vmtronx(mod->name);
 	s->kernel    = 0;
 	s->export    = export;
 	return s;
@@ -608,7 +608,7 @@ static void handle_modversions(struct module *mod, struct elf_info *info,
 	unsigned int crc;
 	enum export export;
 
-	if ((!is_vmlinux(mod->name) || mod->is_dot_o) &&
+	if ((!is_vmtronx(mod->name) || mod->is_dot_o) &&
 	    strncmp(symname, "__ksymtab", 9) == 0)
 		export = export_from_secname(info, get_secindex(info, sym));
 	else
@@ -1932,15 +1932,15 @@ static void read_symbols(char *modname)
 
 	mod = new_module(modname);
 
 	/* When there's no vmlinux, don't print warnings about
 	 * unresolved symbols (since there'll be too many ;) */
-	if (is_vmlinux(modname)) {
-		have_vmlinux = 1;
+	if (is_vmtronx(modname)) {
+		have_vmtronx = 1;
 		mod->skip = 1;
 	}
 
 	license = get_modinfo(info.modinfo, info.modinfo_len, "license");
-	if (info.modinfo && !license && !is_vmlinux(modname))
+	if (info.modinfo && !license && !is_vmtronx(modname))
 		warn("modpost: missing MODULE_LICENSE() in %s\n"
 		     "see include/linux/module.h for "
 		     "more information\n", modname);
@@ -1961,15 +1961,15 @@ static void read_symbols(char *modname)
 		handle_modversions(mod, &info, sym, symname);
 		handle_moddevtable(mod, &info, sym, symname);
 	}
-	if (!is_vmlinux(modname) ||
-	     (is_vmlinux(modname) && vmlinux_section_warnings))
+	if (!is_vmtronx(modname) ||
+	     (is_vmtronx(modname) && vmtronx_section_warnings))
 		check_sec_ref(mod, modname, &info);
 
 	version = get_modinfo(info.modinfo, info.modinfo_len, "version");
 	if (version)
 		maybe_frob_rcs_version(modname, version, info.modinfo,
 				       version - (char *)info.hdr);
-	if (version || (all_versions && !is_vmlinux(modname)))
+	if (version || (all_versions && !is_vmtronx(modname)))
 		get_src_version(modname, mod->srcversion,
 				sizeof(mod->srcversion)-1);
 
@@ -2035,7 +2035,7 @@ void buf_write(struct buffer *buf, const char *s, int len)
 
 static void check_for_gpl_usage(enum export exp, const char *m, const char *s)
 {
-	const char *e = is_vmlinux(m) ?"":".ko";
+	const char *e = is_vmtronx(m) ?"":".ko";
 
 	switch (exp) {
 	case export_gpl:
@@ -2060,7 +2060,7 @@ static void check_for_gpl_usage(enum export exp, const char *m, const char *s)
 
 static void check_for_unused(enum export exp, const char *m, const char *s)
 {
-	const char *e = is_vmlinux(m) ?"":".ko";
+	const char *e = is_vmtronx(m) ?"":".ko";
 
 	switch (exp) {
 	case export_unused:
@@ -2143,7 +2143,7 @@ static int add_versions(struct buffer *b, struct module *mod)
 	for (s = mod->unres; s; s = s->next) {
 		exp = find_symbol(s->name);
 		if (!exp || exp->module == mod) {
-			if (have_vmlinux && !s->weak) {
+			if (have_vmtronx && !s->weak) {
 				if (warn_unresolved) {
 					warn("\"%s\" [%s.ko] undefined!\n",
 					     s->name, mod->name);
@@ -2193,7 +2193,7 @@ static void add_depends(struct buffer *b, struct module *mod,
 	int first = 1;
 
 	for (m = modules; m; m = m->next)
-		m->seen = is_vmlinux(m->name);
+		m->seen = is_vmtronx(m->name);
 
 	buf_printf(b, "\n");
 	buf_printf(b, "static const char __module_depends[]\n");
@@ -2307,8 +2307,8 @@ static void read_dump(const char *fname, unsigned int kernel)
 			goto fail;
 		mod = find_module(modname);
 		if (!mod) {
-			if (is_vmlinux(modname))
-				have_vmlinux = 1;
+			if (is_vmtronx(modname))
+				have_vmtronx = 1;
 			mod = new_module(modname);
 			mod->skip = 1;
 		}
@@ -2332,7 +2332,7 @@ static int dump_sym(struct symbol *sym)
 {
 	if (!external_module)
 		return 1;
-	if (sym->vmlinux || sym->kernel)
+	if (sym->vmtronx || sym->kernel)
 		return 0;
 	return 1;
 }
@@ -2403,7 +2403,7 @@ int main(int argc, char **argv)
 			all_versions = 1;
 			break;
 		case 's':
-			vmlinux_section_warnings = 0;
+			vmtronx_section_warnings = 0;
 			break;
 		case 'S':
 			sec_mismatch_verbose = 0;
@@ -8,7 +8,7 @@
  * of the GNU General Public License, incorporated herein by reference.
  *
- * Usage: modpost vmlinux module1.o module2.o ...
+ * Usage: modpost vmtronx module1.o module2.o ...
  */
 
@@ -1932,15 +1932,15 @@ static void read_symbols(char *modname)
 	mod = new_module(modname);
 
-	/* When there's no vmlinux, don't print warnings about
+	/* When there's no vmtronx, don't print warnings about
 	 * unresolved symbols (since there'll be too many ;) */
diff --git a/tkernel_source/scripts/namespace.pl b/tkernel_source/scripts/namespace.pl
index a71be6b..1f86be2 100644
--- a/tkernel_source/scripts/namespace.pl
+++ b/tkernel_source/scripts/namespace.pl
@@ -17,7 +17,7 @@
 #
 #	The source must be compiled/assembled first, the object files
 #	are the primary input to this script.  Incomplete or missing
 #	objects will result in a flawed analysis.  Compile both vmlinux
 #	and modules.
 #
 #	Even with complete objects, treat the result of the analysis
@@ -206,7 +206,7 @@ sub linux_objects
 		|| m:sound/.*/snd-:
 		|| m:^.*/\.tmp_:
 		|| m:^\.tmp_:
-		|| m:/vmlinux-obj.o$:
+		|| m:/vmtronx-obj.o$:
 		|| m:^tools/:
 		)
 	) {
@@ -17,7 +17,7 @@
 #	The source must be compiled/assembled first, the object files
 #	are the primary input to this script.  Incomplete or missing
-#	objects will result in a flawed analysis.  Compile both vmlinux
+#	objects will result in a flawed analysis.  Compile both vmtronx
 #	and modules.
 #
diff --git a/tkernel_source/scripts/sortextable.c b/tkernel_source/scripts/sortextable.c
index 1052d48..d9c1cb4 100644
--- a/tkernel_source/scripts/sortextable.c
+++ b/tkernel_source/scripts/sortextable.c
@@ -13,7 +13,7 @@
  */
 
 /*
  * Strategy: alter the vmlinux file in-place.
  */
 
 #include <sys/types.h>
@@ -327,7 +327,7 @@ main(int argc, char *argv[])
 	int i;
 
 	if (argc < 2) {
-		fprintf(stderr, "usage: sortextable vmlinux...\n");
+		fprintf(stderr, "usage: sortextable vmtronx...\n");
 		return 0;
 	}
 
@@ -13,7 +13,7 @@
 
 /*
- * Strategy: alter the vmlinux file in-place.
+ * Strategy: alter the vmtronx file in-place.
  */
 
-- 
2.7.4

----8<----------------------------------------------------------------
On Sat, Jan 07, 2017 at 01:39:04PM +0800, Du Huanpeng wrote:
> 使用 KBuild 默认编译出的可执行文件默认的名称为 vmlinux,Open T-Kernel
> 项目编译的并不是 linux,所以有必要改个名字。暂时改名为 vmtronx 吧,后
> 面加了个 x,原因如下:
> 1 加了一个字母(x)之后,名字与原来等长
> 2 字母(x)表示可执行的意义
> 3 压缩后的文件名字可以命名为 vmtronz,可以区分
> 
> --------
> duhuanpeng.
> u74147@xxxxxxxxx
> 

-- 
Copyright (c) 2017 duhuanpeng <u74147@xxxxxxxxx>



References